<?php
/**
 * Plugin Name:  Robo IVR Call Pakistan
 * Plugin URI: Robo IVR Call Pakistan
 * Description: Get our Order Verification over Voice Call plugin today and start verifying orders in a more secure and convenient way!
 * Version: 1.1
 * Author: H3 Technologies (Pvt.) Limited 
 * Author URI: https://www.h3techs.com
 * Developer: H3 Technologies
 * Requires at least: 4.7
**/

if ( !defined( 'ABSPATH' ) ) exit;

include_once('inc/settings.php');
include_once('inc/functions.php');
include_once('inc/logs.php');
include_once('inc/classes.php');
include_once('inc/cron.php');

add_action('admin_menu', 'bsp_robo_menu');
function bsp_robo_menu() {
    add_menu_page(
        'Robo IVR Call', 
        'Robo IVR Call', 
        'manage_options', 
        'bsp_robo_settings', 
        '',
        plugins_url("robo-ivr-call-pakistan/assets/images/icon.png")
    );

    add_submenu_page( 
        'bsp_robo_settings', 
        'Settings', 
        'Settings',
        'manage_options', 
        'bsp_robo_settings', 
        'bsp_robo_settings_page'
    );

    add_submenu_page( 
        'bsp_robo_settings', 
        'Call Logs', 
        'Call Logs',
        'manage_options', 
        'bsp_robo_logs_page', 
        'bsp_robo_logs_page'
    );
}

add_filter('plugin_action_links_' . plugin_basename( __FILE__ ), 'bsp_robo_plugin_settings_link');
function bsp_robo_plugin_settings_link($links) {
    $plugin_links = array(
        '<a href="' . admin_url( 'admin.php?page=bsp_robo_settings' ) . '">' . __( 'Settings', '' ) . '</a>',
        '<a href="https://www.youtube.com/" target="_blank">' . __( 'Guide', '' ) . '</a>'
    );
    return array_merge($plugin_links, $links);
}

function bsp_robo_create_table() {
    global $wpdb;

    $charset_collate = $wpdb->get_charset_collate();
        
    $table_name = $wpdb->prefix . 'bsp_robo_logs';
    $sql = "CREATE TABLE $table_name (
        `id` int(11) NOT NULL AUTO_INCREMENT,
        `shop_url` varchar(255) NULL,
        `order_type` varchar(50) NULL,
        `order_id` varchar(50) NULL,
        `order_number` varchar(50) NULL,
        `order_phone` varchar(50) NULL,
        `order_total` varchar(50) NULL,
        `order_gateway` varchar(50) NULL,
        `ivr_provider` varchar(50) NULL,
        `ivr_datetime` datetime NULL,        
        `ivr_id` varchar(50) NULL,
        `ivr_api` varchar(50) NULL,
        `ivr_response` varchar(50) NULL,
        `ivr_api_return` varchar(50) NULL,
        `ivr_retry` varchar(50) NULL,
        `ivr_call` varchar(50) NULL,
        `ivr_status` varchar(50) NULL,
        `ivr_logs` text NULL,
        `ivr_call_que` varchar(255) NULL,
      PRIMARY KEY (`id`),
      KEY `shop_url` (`shop_url`)
    ) $charset_collate;";

    $table_name = $wpdb->prefix . 'bsp_robo_settings';
    $sql1 = "CREATE TABLE  $table_name (
       `id` int(11) NOT NULL AUTO_INCREMENT,
        `bspivr_email` varchar(255) NULL,
        `bspivr_key` varchar(255) NULL,
        `bspivr_voiceid` int(11) NULL,
        `enable_confirmed_order` tinyint(1) NULL DEFAULT 1,
        `enable_cancelled_order` tinyint(1) NULL DEFAULT 1,
        `enable_callback_order` tinyint(1) NULL DEFAULT 1,
        `enable_auto_call` tinyint(1) NULL DEFAULT 1,
        `billing_phone` tinyint(1) NULL DEFAULT 0,
        `international_calls` tinyint(1) NULL DEFAULT 0,
        `cod` tinyint(1) NULL DEFAULT 0,
        `bacs` tinyint(1) NULL DEFAULT 0,
        `cheque` tinyint(1) NULL DEFAULT 0,
        `other` tinyint(1) NULL DEFAULT 0,
      UNIQUE KEY id(`id`)  
    ) $charset_collate;";

    require_once(ABSPATH .'wp-admin/includes/upgrade.php');

    dbDelta($sql);
    dbDelta($sql1);
}

function bsp_robo_delete_table() {
    global $wpdb;
    $table_name = $wpdb->prefix . "bsp_robo_logs";
    $sql        = "DROP TABLE IF EXISTS $table_name;";
    $wpdb->query($sql);
    delete_option("1.0");

    $table_name = $wpdb->prefix . "bsp_robo_settings";
    $sql        = "DROP TABLE IF EXISTS $table_name;";
    $wpdb->query($sql);
    delete_option("1.0");    
}

register_activation_hook(__FILE__, 'bsp_robo_create_table' );
register_deactivation_hook(__FILE__, 'bsp_robo_delete_table' );

function bsp_robo_get_settings() {
    global $wpdb;
    $table_name = $wpdb->prefix . "bsp_robo_settings";
    $data = $wpdb->get_results("SELECT * FROM `$table_name`");
    return $data;   
}

function bsp_robo_check_account($email, $key){
    $data   = "email=".$email."&key=".$key."&type=verify";
    $url    ='https://secure.h3techs.com/sms/api/mask?'.$data;
    $result = wp_remote_retrieve_body(wp_remote_get($url));
    return json_decode($result)->sms->code;
}

add_action('wp_ajax_bsp_robo_settings', 'bsp_robo_save_settings');

function bsp_robo_save_settings() {
    $bspivr_email = sanitize_text_field($_REQUEST["bspivr_email"]);
    if(!is_email($bspivr_email)){ echo json_encode(array("status"=>false,"message"=>"Email is not valid")); wp_die(); }

    $bspivr_key             = sanitize_text_field($_REQUEST['bspivr_key']);
    $bspivr_key             = esc_html($bspivr_key);
    $bspivr_voiceid         = esc_html(sanitize_text_field($_REQUEST['bspivr_voiceid']));
    $enable_confirmed_order = esc_html(sanitize_text_field($_REQUEST['enable_confirmed_order']));
    $enable_cancelled_order = esc_html(sanitize_text_field($_REQUEST['enable_cancelled_order']));
    $enable_callback_order  = esc_html(sanitize_text_field($_REQUEST['enable_callback_order']));
    $enable_auto_call       = esc_html(sanitize_text_field($_REQUEST['enable_auto_call']));
    $billing_phone          = esc_html(sanitize_text_field($_REQUEST['billing_phone']));
    $international_calls    = esc_html(sanitize_text_field($_REQUEST['international_calls']));
    $cod                    = esc_html(sanitize_text_field($_REQUEST['cod']));
    $bacs                   = esc_html(sanitize_text_field($_REQUEST['bacs']));
    $cheque                 = esc_html(sanitize_text_field($_REQUEST['cheque']));
    $other                  = esc_html(sanitize_text_field($_REQUEST['other']));
    $check                  = bsp_robo_check_account($bspivr_email, $bspivr_key);
    if($check==200) {
        global $wpdb;
        $wpdb                -> query('TRUNCATE TABLE '.$wpdb->prefix.'bsp_robo_settings');
        $wpdb                -> query("INSERT INTO `".$wpdb->prefix."bsp_robo_settings` (`bspivr_email`, `bspivr_key`, `bspivr_voiceid`, `enable_confirmed_order`, `enable_cancelled_order`, `enable_callback_order`, `enable_auto_call`,  `billing_phone`, `international_calls`, `cod`, `bacs`, `cheque`, `other`) VALUES ('$bspivr_email', '$bspivr_key', '$bspivr_voiceid', '$enable_confirmed_order', '$enable_cancelled_order', '$enable_callback_order', '$enable_auto_call', '$billing_phone', '$international_calls', '$cod', '$bacs', '$cheque', '$other');");
        $response['success'] = true;
        $response['message'] = "Updated";
    } else {
        $response['success'] = false;
        $response['message'] = "These Credentials Does Not Match With Our Records";
    }
    echo json_encode($response);
    wp_die();
}
?>